# Tengeralattjárók

Mega Building Collection: Record-Breaking Submarines
63 perc, 2023

- Értesítőt kérek
- Bakancslista
- Megosztom

## Értékelés:

1 szavazatból
Szerinted?

Szólj hozzá!

+ 3 kép
+ 9 kép

## Értékelés:

1 szavazatból
Szerinted?

Szólj hozzá!
Vetítések:
5:05, vasárnap (december 08.)
Spektrum

Az aktuális rész ismertetője: A tengeralattjárók a technológia csúcsai. Ilyen a Redoutable, amely 16 nukleáris rakétát képes szállítani. Vagy a Suffren, egy igazi vízalatti ragadozó. És itt van a Rubis is, a II. világháborús veterán.

Teljes leírás

Hozzászólások (0)
Szerkeszd te is a Port.hu-t!

#### Ha hiányosságot találsz, vagy valamihez van valamilyen érdekes hozzászólásod, írd meg nekünk!

Küldés

Figyelem: A beküldött észrevételeket a szerkesztőink értékelik, csak azok a javasolt változtatások valósulhatnak meg, amik jóváhagyást kapnak. Kérjük, forrásmegjelöléssel támaszd alá a leírtakat!

## Hozzászólások

Spoiler
Offtopik
Szerinted?

Vetítések:
5:05, vasárnap (december 08.)
Spektrum

# Címlapon

tv 2025-ben visszatér a Csillag születik! az RTL-en
tv Megvan az X-Faktor 2024 győztese
tv Ezeket a filmeket ajánljuk vasárnapra
magazin Vasárnapi programajánló
tv Családi filmek vasárnapra

# Legolvasottabb cikkeink

mozi 8 elképesztő időutazós sci-fi, amiről talán nem is hallottál
mozi 60 éves Marisa Tomei, akinek még mi sem adtuk volna oda azt a bizonyos Oscart, pedig imádjuk
mozi Ez a 4 film elérte azt, hogy párkapcsolatokat tegyen tönkre
magazin Unod a sablonokat? Íme 5 tökéletesen eredeti film
stream A svédek hozták el a Netflix idei legjobb sorozatát
mozi Ez az 5 legbénább filmes fordulat

# PORT.hu a Facebookon

##### Figyelmeztetés

Az értesítések jelenleg le vannak tiltva! Amennyiben szeretnél cikkajánlókat kapni, kérlek, hogy a böngésző Beállítások / Értesítések menüpontja alatt állítsd be az értesítések engedélyezését!

## Bejelentkezés

Jelentkezz be!

Belépek Facebookkal
VAGY
Hibás email cím vagy jelszó!
Elfelejtettem a jelszavam
Maradjak belépve
Regisztrálok»